# AUTOGENERATED! DO NOT EDIT! File to edit: 00_core.ipynb (unless otherwise specified).

__all__ = ['say_hello', 'say_hello2']

# Cell
def say_hello(to):
    "Say hello to somebody"
    return f'Hello: {to}!'

def say_hello2(to):
    "Say hello to somebody"
    return f'Hello: {to}!'


# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"say_hello": "00_core.ipynb",
         "say_hello2": "00_core.ipynb"}

modules = ["core.py"]

doc_url = "https://andrewm4894.github.io/am4894bq/"

git_url = "https://github.com/andrewm4894/am4894bq/tree/master/"

def custom_doc_links(name): return None
